/*
** Module   : MessageTypes.java
** Abstract : defines all valid message types
**
** Copyright (c) 2007-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description------------------------------
** 001 GES 20070111   @31790 Moved the constants here from the Message
**                           class to make it easy for other code to
**                           reference the constants.
** 002 GES 20070115   @31834 Added INIT_CONVERSATION type and changed INIT
**                           to INIT_STANDARD.
** 003 ECF 20071102   @35883 Added INIT_ROUTER type.
** 004 CA  20130822          Fixed the net protocol to support async requests.
*/

package com.goldencode.p2j.net;

/**
 * Defines all valid message types for the distributed application protocol.
 */
public interface MessageTypes
{
   /** A name to node or node to name look-up request. */
   public static final int ADDRESS_REQUEST = 1;

   /** A test message requesting a protocol-level reply. */
   public static final int ECHO = 2;

   /** A request for the assignment of a node address. */
   public static final int INIT_STANDARD = 3;

   /** A request for the assignment of a node address in conversation mode. */
   public static final int INIT_CONVERSATION = 4;

   /** A synchronous request for processing. */
   public static final int REQUEST_SYNCH = 5;

   /** A message that will be sent to the other side asynchronously. */
   public static final int REQUEST_ASYNCH = 6;
   
   /** A notification that a new router-to-router connection was created. */
   public static final int INIT_ROUTER = 7;

   /** An artificial boundary to ease finding the beginning of reply types. */
   public static final int BEGIN_REPLY = 100;

   /** A name or node look-up response. */
   public static final int ADDRESS_REPLY = 101;

   /** The response to an ECHO request. */
   public static final int ECHO_REPLY = 102;

   /** Contains the dynamically assigned address for the node. */
   public static final int INIT_REPLY = 103;

   /** A successful response to a synchronous request. */
   public static final int REPLY_SYNC = 104;

   /** A successful response to an asynchronous request. */
   public static final int REPLY_ASYNC = 105;

   /** An unsuccessful response or error condition response to a synchronous request. */
   public static final int REPLY_EXCEPTION_SYNC = 106;

   /** An unsuccessful response or error condition response to an asynchronous request. */
   public static final int REPLY_EXCEPTION_ASYNC = 107;

   /** An artificial boundary to ease finding the end of reply types. */
   public static final int END_REPLY = 108;
   
   /** An invalid type. */
   public static final int UNKNOWN = 999;
}
