/*
** Module   : AsyncRequestListener.java
** Abstract : provides a callback mechanism to listen for async request notifications. 
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20130813 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Provides a callback mechanism to listen for async request notifications. Before the async 
 * request is invoked, {@link #notifyStart()} will be called. After the async request is finished,
 * {@link #notifyFinish()} will be called; this will be done before the PROCEDURE-COMPLETE event
 * or the EVENT-PROCEDURE is invoked.
 */
public interface AsyncRequestListener
{
   /**
    * Notify an asynchronous request is started.
    */
   public void notifyStart();

   /**
    * Notify when an asynchronous request is finished.
    */
   public void notifyFinish();
}
